package com.mindoo.ftp.config.nsf;

import lotus.domino.Database;
import lotus.domino.NotesException;
import lotus.domino.Session;

/**
 * Utility class that locates the FTP server configuration database
 * 
 * @author Karsten Lehmann
 */
public class FTPDbLocator {
	/** Default name of FTP server config */
	public static final String DEFAULT_CONFIG_PATH = "mindoo-ftp-config.nsf";
	/** Default path of FTP server log */
	public static final String DEFAULT_LOG_PATH = "mindoo-ftp-config-log.nsf";
	
	/**
	 * The method reads the location for the configuration database from the
	 * Notes.ini variable $mndFTPConfig and opens the database
	 * 
	 * @param session session
	 * @return database or <code>null</code> if not found
	 * @throws NotesException
	 */
	public static Database getConfigDatabase(Session session) throws NotesException {
		String configLocationFromIni=session.getEnvironmentString("mndFTPConfig");
		if (configLocationFromIni==null || configLocationFromIni.length()==0) {
			configLocationFromIni=DEFAULT_CONFIG_PATH;
		}
		String dbServer="";
		String dbFilePath=null;
		int iPos=configLocationFromIni.indexOf("!!");
		if (iPos!=-1) {
			//string contains separator !! between server and filepath
			if (iPos>0)
				dbServer=configLocationFromIni.substring(0,iPos);
			dbFilePath=configLocationFromIni.substring(iPos+2);
		}
		else {
			//string contains filepath on local machine
			dbFilePath=configLocationFromIni;
		}
		//try to find the database:
		Database configDb=session.getDatabase(dbServer, dbFilePath, false);
		return configDb;
	}
	
	/**
	 * The method reads the location for the log database from the
	 * Notes.ini variable $mndFTPLog and opens the database
	 * 
	 * @param session session
	 * @return database or <code>null</code> if not found
	 * @throws NotesException
	 */
	public static Database getLogDatabase(Session session) throws NotesException {
		String logLocationFromIni=session.getEnvironmentString("mndFTPLog");
		if (logLocationFromIni==null || logLocationFromIni.length()==0) {
			logLocationFromIni=DEFAULT_LOG_PATH;
		}
		String dbServer="";
		String dbFilePath=null;
		int iPos=logLocationFromIni.indexOf("!!");
		if (iPos!=-1) {
			//string contains separator !! between server and filepath
			if (iPos>0)
				dbServer=logLocationFromIni.substring(0,iPos);
			dbFilePath=logLocationFromIni.substring(iPos+2);
		}
		else {
			//string contains filepath on local machine
			dbFilePath=logLocationFromIni;
		}
		//try to find the database:
		Database logDb=session.getDatabase(dbServer, dbFilePath, false);
		return logDb;
	}

}
